@@ -1,10 +1,17 @@
 from importlib import import_module
 from pprint import pformat
 from datetime import datetime
+from time import timezone
 
 from floraconcierge import errors
 
 
+
+# If int value is greater then this constant, object will have field ${field}_date which will be datetime type.
+# Date 05.11.1985. Too big value for usual usage and fine date :)
+MIN_INT_TO_DATETIME = 500000000
+
+
 def module_name_from_class(cls):
     class_name = ('floraconcierge.mapping.%s' % cls.replace("_", '.').lower()).split('.')
     module, name = ".".join(class_name[:-1]), class_name[-1].capitalize()
@@ -40,6 +47,7 @@ class Object(object):
         if '_className' in kwargs:
             del kwargs['_className']
 
+        extra = {}
         for k, v in kwargs.iteritems():
             try:
                 v = int(v)
@@ -49,9 +57,17 @@ class Object(object):
                 except (ValueError, TypeError):
                     pass
 
+            magic_date = '%s_date' % k
+            if isinstance(v, (int, float)) and v > MIN_INT_TO_DATETIME and magic_date not in kwargs:
+                try:
+                    extra[magic_date] = datetime.utcfromtimestamp(v)
+                except:
+                    extra[magic_date] = None
+
             kwargs[k] = v
 
         self.__dict__.update(kwargs)
+        self.__dict__.update(extra)
 
     def __repr__(self):
         return '<%s %s>' % (self.__class__.__name__, pformat(self.__dict__))
