@@ -132,10 +132,11 @@ def submit_review(postObject):
     return get_apiclient().services.shop.submit_review(postObject)
 
 
-def get_reviews(limit=None, offset=None):
+def get_reviews(limit=None, offset=None, product_id=None):
     return get_apiclient().services.shop.get_reviews(
         limit=limit,
-        offset=offset)
+        offset=offset,
+        product_id=product_id)
 
 
 def get_cash_salons_cities(country_id):
